==> heaserver_people-1.9.1.tar.gz: heaserver_people-1.9.1/tests/heaserver/persontest/testcase.py <==
"""
Creates a test case class for use with the unittest library that is built into Python.
"""

from heaserver.service.testcase.microservicetestcase import get_test_case_cls_default
from heaserver.person import service
from heaobject.user import NONE_USER, ALL_USERS, CREDENTIALS_MANAGER_USER
from heaobject.root import Permission
from heaserver.service.testcase.expectedvalues import Action
from heaserver.person.keycloakmockmongotestcase import KeycloakMockMongoManager

db_store = {
    service.MONGODB_PERSON_COLLECTION: [{
        'id': 'system|none',
        'instance_id': 'heaobject.person.Person^system|none',
        'created': None,  # KeycloakMongoForPyTest sets created to None, overriding what comes back from Keycloak because we can't control it. System users don't have a created timestamp.
        'derived_by': None,
        'derived_from': [],
        'description': None,
        'display_name': 'Reximus Max',
        'invites': [],
        'modified': None,
        'name': 'reximusmax',
        'owner': NONE_USER,
        'shares': [{
            'invite': None,
            'permissions': ['VIEWER'],
            'type': 'heaobject.root.ShareImpl',
            'user': ALL_USERS,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }, {
            'invite': None,
            'permissions': ['EDITOR'],
            'type': 'heaobject.root.ShareImpl',
            'user': CREDENTIALS_MANAGER_USER,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }],
        'user_shares': [{
            'invite': None,
            'permissions': ['VIEWER'],
            'type': 'heaobject.root.ShareImpl',
            'user': ALL_USERS,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }, {
            'invite': None,
            'permissions': ['EDITOR'],
            'type': 'heaobject.root.ShareImpl',
            'user': CREDENTIALS_MANAGER_USER,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }],
        'group_shares': [],
        'source': None,
        'source_detail': None,
        'first_name': 'Reximus',
        'last_name': 'Max',
        'full_name': 'Reximus Max',
        'type': 'heaobject.person.Person',
        'title': None,
        'phone_number': None,
        'preferred_name': None,
        'email': None,
        'type_display_name': 'Person',
        'group_ids': [],
        'super_admin_default_permissions': [p.name for p in Permission if p is not Permission.CREATOR],
        'dynamic_permission_supported': False
    },
        {
            'id': 'system|test',
            'instance_id': 'heaobject.person.Person^system|test',
            'created': None,
            'derived_by': None,
            'derived_from': [],
            'description': None,
            'display_name': 'Luximus Max',
            'invites': [],
            'modified': None,
            'name': 'luximusmax',
            'owner': NONE_USER,
            'shares': [{
                'invite': None,
                'permissions': ['VIEWER'],
                'type': 'heaobject.root.ShareImpl',
                'user': ALL_USERS,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }, {
                'invite': None,
                'permissions': ['EDITOR'],
                'type': 'heaobject.root.ShareImpl',
                'user': CREDENTIALS_MANAGER_USER,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }],
            'user_shares': [{
                'invite': None,
                'permissions': ['VIEWER'],
                'type': 'heaobject.root.ShareImpl',
                'user': ALL_USERS,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }, {
                'invite': None,
                'permissions': ['EDITOR'],
                'type': 'heaobject.root.ShareImpl',
                'user': CREDENTIALS_MANAGER_USER,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }],
            'group_shares': [],
            'source': None,
            'source_detail': None,
            'first_name': 'Luximus',
            'last_name': 'Max',
            'full_name': 'Luximus Max',
            'type': 'heaobject.person.Person',
            'title': None,
            'phone_number': None,
            'preferred_name': None,
            'email': None,
            'type_display_name': 'Person',
            'group_ids': [],
            'super_admin_default_permissions': [p.name for p in Permission if p is not Permission.CREATOR],
            'dynamic_permission_supported': False
        }]}

TestCase = get_test_case_cls_default(coll=service.MONGODB_PERSON_COLLECTION,
                                     wstl_package=service.__package__,
                                     db_manager_cls=KeycloakMockMongoManager,
                                     href='http://localhost:8080/people/',
                                     fixtures=db_store,
                                     get_actions=[Action(name='heaserver-people-person-get-properties',
                                                         rel=['hea-properties']),
                                                  Action(name='heaserver-people-person-get-self',
                                                         url='http://localhost:8080/people/{id}',
                                                         rel=['self']),
                                                #   Action(name='heaserver-people-person-get-settings',
                                                #          url='http://localhost:8080/collections/heaobject.settings.SettingsObject',
                                                #          rel=['hea-system-menu-item', 'hea-user-menu-item',
                                                #               'application/x.settingsobject',
                                                #               'application/x.collection']),
                                                  # Action(name='heaserver-people-person-get-organization-collection',
                                                  #        url='http://localhost:8080/collections/heaobject.organization.Organization',
                                                  #        rel=['hea-system-menu-item', 'application/x.collection']),
                                                  #   Action(name='heaserver-people-person-get-volumes-collection',
                                                  #          url='http://localhost:8080/collections/heaobject.volume.Volume',
                                                  #          rel=['hea-system-menu-item', 'application/x.collection']),
                                                  Action(name='heaserver-people-person-get-organizations',
                                                         url='http://localhost:8080/organizations/',
                                                         rel=['application/x.organization']),
                                                  Action(name='heaserver-people-person-get-volumes',
                                                         url='http://localhost:8080/volumes/',
                                                         rel=['application/x.volume']),
                                                  Action(name='heaserver-people-person-get-desktop-object-actions',
                                                         url='http://localhost:8080/desktopobjectactions/',
                                                         rel=['application/x.desktopobjectaction']),
                                                #   Action(name='heaserver-people-person-get-credential-collection',
                                                #          url='http://localhost:8080/collections/heaobject.keychain.CredentialsView',
                                                #          rel=['hea-system-menu-item', 'application/x.collection'])
                                                  ],
                                     get_all_actions=[Action(name='heaserver-people-person-get-properties',
                                                             rel=['hea-properties']),
                                                      Action(name='heaserver-people-person-get-self',
                                                             url='http://localhost:8080/people/{id}',
                                                             rel=['self']),
                                                    #   Action(name='heaserver-people-person-get-settings',
                                                    #          url='http://localhost:8080/collections/heaobject.settings.SettingsObject',
                                                    #          rel=['hea-system-menu-item', 'hea-user-menu-item',
                                                    #               'application/x.settingsobject',
                                                    #               'application/x.collection']),
                                                      # Action(name='heaserver-people-person-get-organization-collection',
                                                      #        url='http://localhost:8080/collections/heaobject.organization.Organization',
                                                      #        rel=['hea-system-menu-item', 'application/x.collection']),
                                                      #   Action(name='heaserver-people-person-get-volumes-collection',
                                                      #      url='http://localhost:8080/collections/heaobject.volume.Volume',
                                                      #      rel=['hea-system-menu-item', 'application/x.collection']),
                                                      Action(name='heaserver-people-person-get-organizations',
                                                             url='http://localhost:8080/organizations/',
                                                             rel=['application/x.organization']),
                                                      Action(name='heaserver-people-person-get-volumes',
                                                             url='http://localhost:8080/volumes/',
                                                             rel=['application/x.volume']),
                                                      Action(name='heaserver-people-person-get-desktop-object-actions',
                                                             url='http://localhost:8080/desktopobjectactions/',
                                                             rel=['application/x.desktopobjectaction']),
                                                    #   Action(name='heaserver-people-person-get-credential-collection',
                                                    #          url='http://localhost:8080/collections/heaobject.keychain.CredentialsView',
                                                    #          rel=['hea-system-menu-item', 'application/x.collection'])
                                                             ],
                                     duplicate_action_name=None,
                                     exclude=['body_put', 'body_post'])

==> heaserver_people-1.9.4.tar.gz: heaserver_people-1.9.4/tests/heaserver/persontest/testcase.py <==
"""
Creates a test case class for use with the unittest library that is built into Python.
"""

from heaserver.service.testcase.microservicetestcase import get_test_case_cls_default
from heaserver.person import service
from heaobject.user import NONE_USER, ALL_USERS, CREDENTIALS_MANAGER_USER
from heaobject.root import Permission
from heaserver.service.testcase.expectedvalues import Action
from heaserver.person.keycloakmockmongotestcase import KeycloakMockMongoManager

db_store = {
    service.MONGODB_PERSON_COLLECTION: [{
        'id': 'system|none',
        'instance_id': 'heaobject.person.Person^system|none',
        'created': None,  # KeycloakMongoForPyTest sets created to None, overriding what comes back from Keycloak because we can't control it. System users don't have a created timestamp.
        'derived_by': None,
        'derived_from': [],
        'description': None,
        'display_name': 'Reximus Max',
        'invites': [],
        'modified': None,
        'name': 'reximusmax',
        'owner': NONE_USER,
        'shares': [{
            'invite': None,
            'permissions': ['VIEWER'],
            'type': 'heaobject.root.ShareImpl',
            'user': ALL_USERS,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }, {
            'invite': None,
            'permissions': ['EDITOR'],
            'type': 'heaobject.root.ShareImpl',
            'user': CREDENTIALS_MANAGER_USER,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }],
        'user_shares': [{
            'invite': None,
            'permissions': ['VIEWER'],
            'type': 'heaobject.root.ShareImpl',
            'user': ALL_USERS,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }, {
            'invite': None,
            'permissions': ['EDITOR'],
            'type': 'heaobject.root.ShareImpl',
            'user': CREDENTIALS_MANAGER_USER,
            'group': NONE_USER,
            'type_display_name': 'Share',
            'basis': 'USER'
        }],
        'group_shares': [],
        'source': None,
        'source_detail': None,
        'first_name': 'Reximus',
        'last_name': 'Max',
        'full_name': 'Reximus Max',
        'type': 'heaobject.person.Person',
        'title': None,
        'phone_number': None,
        'preferred_name': None,
        'email': None,
        'type_display_name': 'Person',
        'group_ids': [],
        'super_admin_default_permissions': [Permission.VIEWER.name],
        'dynamic_permission_supported': False
    },
        {
            'id': 'system|test',
            'instance_id': 'heaobject.person.Person^system|test',
            'created': None,
            'derived_by': None,
            'derived_from': [],
            'description': None,
            'display_name': 'Luximus Max',
            'invites': [],
            'modified': None,
            'name': 'luximusmax',
            'owner': NONE_USER,
            'shares': [{
                'invite': None,
                'permissions': ['VIEWER'],
                'type': 'heaobject.root.ShareImpl',
                'user': ALL_USERS,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }, {
                'invite': None,
                'permissions': ['EDITOR'],
                'type': 'heaobject.root.ShareImpl',
                'user': CREDENTIALS_MANAGER_USER,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }],
            'user_shares': [{
                'invite': None,
                'permissions': ['VIEWER'],
                'type': 'heaobject.root.ShareImpl',
                'user': ALL_USERS,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }, {
                'invite': None,
                'permissions': ['EDITOR'],
                'type': 'heaobject.root.ShareImpl',
                'user': CREDENTIALS_MANAGER_USER,
                'group': NONE_USER,
                'type_display_name': 'Share',
                'basis': 'USER'
            }],
            'group_shares': [],
            'source': None,
            'source_detail': None,
            'first_name': 'Luximus',
            'last_name': 'Max',
            'full_name': 'Luximus Max',
            'type': 'heaobject.person.Person',
            'title': None,
            'phone_number': None,
            'preferred_name': None,
            'email': None,
            'type_display_name': 'Person',
            'group_ids': [],
            'super_admin_default_permissions': [Permission.VIEWER.name],
            'dynamic_permission_supported': False
        }]}

TestCase = get_test_case_cls_default(coll=service.MONGODB_PERSON_COLLECTION,
                                     wstl_package=service.__package__,
                                     db_manager_cls=KeycloakMockMongoManager,
                                     href='http://localhost:8080/people/',
                                     fixtures=db_store,
                                     get_actions=[Action(name='heaserver-people-person-get-properties',
                                                         rel=['hea-properties']),
                                                  Action(name='heaserver-people-person-get-self',
                                                         url='http://localhost:8080/people/{id}',
                                                         rel=['self']),
                                                #   Action(name='heaserver-people-person-get-settings',
                                                #          url='http://localhost:8080/collections/heaobject.settings.SettingsObject',
                                                #          rel=['hea-system-menu-item', 'hea-user-menu-item',
                                                #               'application/x.settingsobject',
                                                #               'application/x.collection']),
                                                  # Action(name='heaserver-people-person-get-organization-collection',
                                                  #        url='http://localhost:8080/collections/heaobject.organization.Organization',
                                                  #        rel=['hea-system-menu-item', 'application/x.collection']),
                                                  #   Action(name='heaserver-people-person-get-volumes-collection',
                                                  #          url='http://localhost:8080/collections/heaobject.volume.Volume',
                                                  #          rel=['hea-system-menu-item', 'application/x.collection']),
                                                  Action(name='heaserver-people-person-get-organizations',
                                                         url='http://localhost:8080/organizations/',
                                                         rel=['application/x.organization']),
                                                  Action(name='heaserver-people-person-get-volumes',
                                                         url='http://localhost:8080/volumes/',
                                                         rel=['application/x.volume']),
                                                  Action(name='heaserver-people-person-get-desktop-object-actions',
                                                         url='http://localhost:8080/desktopobjectactions/',
                                                         rel=['application/x.desktopobjectaction']),
                                                #   Action(name='heaserver-people-person-get-credential-collection',
                                                #          url='http://localhost:8080/collections/heaobject.keychain.CredentialsView',
                                                #          rel=['hea-system-menu-item', 'application/x.collection'])
                                                  ],
                                     get_all_actions=[Action(name='heaserver-people-person-get-properties',
                                                             rel=['hea-properties']),
                                                      Action(name='heaserver-people-person-get-self',
                                                             url='http://localhost:8080/people/{id}',
                                                             rel=['self']),
                                                    #   Action(name='heaserver-people-person-get-settings',
                                                    #          url='http://localhost:8080/collections/heaobject.settings.SettingsObject',
                                                    #          rel=['hea-system-menu-item', 'hea-user-menu-item',
                                                    #               'application/x.settingsobject',
                                                    #               'application/x.collection']),
                                                      # Action(name='heaserver-people-person-get-organization-collection',
                                                      #        url='http://localhost:8080/collections/heaobject.organization.Organization',
                                                      #        rel=['hea-system-menu-item', 'application/x.collection']),
                                                      #   Action(name='heaserver-people-person-get-volumes-collection',
                                                      #      url='http://localhost:8080/collections/heaobject.volume.Volume',
                                                      #      rel=['hea-system-menu-item', 'application/x.collection']),
                                                      Action(name='heaserver-people-person-get-organizations',
                                                             url='http://localhost:8080/organizations/',
                                                             rel=['application/x.organization']),
                                                      Action(name='heaserver-people-person-get-volumes',
                                                             url='http://localhost:8080/volumes/',
                                                             rel=['application/x.volume']),
                                                      Action(name='heaserver-people-person-get-desktop-object-actions',
                                                             url='http://localhost:8080/desktopobjectactions/',
                                                             rel=['application/x.desktopobjectaction']),
                                                    #   Action(name='heaserver-people-person-get-credential-collection',
                                                    #          url='http://localhost:8080/collections/heaobject.keychain.CredentialsView',
                                                    #          rel=['hea-system-menu-item', 'application/x.collection'])
                                                             ],
                                     duplicate_action_name=None,
                                     exclude=['body_put', 'body_post'])
